import smbus
import time
        
class I2CDevice:
    """
    Create new I2C device.

    :param address: Device address. Example 0x20.
    :type address: int

    :param busID: I2C bus id. Example 1.
    :type busID: int
    """
    
    def __init__(self, address, busID):
        self.slaveAddress = address
        self.bus = smbus.SMBus(busID)

    def getRelaysStatus(self):
        """
        Get all(16) relays status.
        """
        data = self.bus.read_i2c_block_data(self.slaveAddress,30)
        relays1 = [char for char in format(data[1],'b').zfill(8)][::-1]
        relays2 = [char for char in format(data[2],'b').zfill(8)][::-1]
        return [*relays1, *relays2]
    def getIRStatus(self):
        """
        Get all(16) IRs status.
        """
        data = self.bus.read_i2c_block_data(self.slaveAddress,30)
        ir1 = [char for char in format(data[3],'b').zfill(8)][::-1]
        ir2 = [char for char in format(data[4],'b').zfill(8)][::-1]
        return [*ir1, *ir2]
    def openRelay(self, id):
        """
        Set a relay status.

        :param id: Relay id.(1-16)
        :type id: int
        """
        self.bus.write_byte(self.slaveAddress, int("0x{}".format(id),16))
        time.sleep(1)
        return -1
